#!/usr/bin/env python3
# -*- coding: utf-8 -*-




from katoptron.eigenvalues import *
import os
import fwk
"""@package docstring
This file is used to loop over cases and samples and plot their mechanical properties and solution fields.
"""

import vtk
import tboxVtk
import tboxVtk.reader as vtkR
import tboxVtk.cutter as vtkC

from katoptron.CMAME.model import Compute_QoIs
import matplotlib2tikz
from scipy import stats


def write_tikz_hist(filename, bins, n):
    f = open(filename, 'w')
    print('\\path [fill=c2, fill opacity=0.5] (axis cs:' + str(
        bins[0]) + ', 0)', file=f)
    for i in range(0, len(n)):
        print('--(axis cs:' + str(bins[i]) + ', ' + str(n[i]) + ')', file=f)
        print('--(axis cs:' + str(bins[i + 1]) + ', ' + str(n[i]) + ')', file=f)
    print('--(axis cs:' + str(bins[-1]) + ', 0)', file=f)
    print('--cycle;', file=f)
    f.closed


def main():
    import matplotlib.pyplot as plt

    file_dir = os.path.dirname(__file__)

    current_dir = os.getcwd()

    npzfile = np.load(
        current_dir +
        '/../katoptron_CMAME_tests_post_process_plate_MC_QoI/qois_s1.npz')
    QoIs = npzfile['QoIs']

    n, bins, patches = plt.hist(QoIs[0, :],
                                100,
                                density=True,
                                facecolor='g',
                                alpha=0.75)
    write_tikz_hist('QoI_s1.tex', bins, n)

    kde = stats.gaussian_kde(QoIs[0, :])

    x = np.linspace(1500., 5000., 100)

    p = kde(x)

    plt.figure()
    plt.plot(x, p)
    matplotlib2tikz.save("kde_s1.tex")


if __name__ == "__main__":
    main()
