




import numpy
import vtk

from katoptron.Juelich.post_process.vtk_post_process import *
import os


def compute_qoi(filename, mm=True, scale_x=1.):
    reader = vtk.vtkXMLPUnstructuredGridReader()
    reader.SetFileName(filename)
    reader.Update()

    scale = 1.
    if mm:
        scale = 1000.

    OX = 0.0529999991413206 * scale * scale_x  # *10
    OY = 0.0440000002272427 * scale * scale_x  # *10
    OZ = -0.038604540600378885 * scale * scale_x  # *10
    # Previously: -0.0413666241463175

    F1 = compute_integrated_F(6, 8, OX, OY, OZ, 0, 0, 1, reader)
    F2 = compute_integrated_F(7, 8, OX, OY, OZ, 0, 0, 1, reader)
    F3 = compute_integrated_F(8, 8, OX, OY, OZ, 0, 0, 1, reader)
    return F1, F2, F3


def compute_and_write_preloads(base_dir, filename_out, N, ensemble_size,
                               n_qoi):
    preloads = np.zeros((N, n_qoi))

    N_ensemble = N // ensemble_size
    for ensemble_index in range(0, N_ensemble):
        for l in range(0, ensemble_size):
            filename = base_dir + str(ensemble_size) + '/' + str(
                ensemble_index
            ) + '/fused_mirror_assembly_mm_part_2_ast1_s' + str(l) + '.pvtu'
            F1, F2, F3 = compute_qoi(filename)
            preloads[ensemble_index * ensemble_size + l, 0] = F1
            preloads[ensemble_index * ensemble_size + l, 1] = F2
            preloads[ensemble_index * ensemble_size + l, 2] = F3

    np.savetxt(filename_out, preloads)
    return preloads


def main():

    file_dir = os.path.dirname(__file__)

    compute = False
    if compute:
        N = 2
        ensemble_size = 1
        n_qoi = 3

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused/MPI_2/A2/'
        preloads_A2 = compute_and_write_preloads(base_dir, 'preloads_A2.txt',
                                                 N, ensemble_size, n_qoi)
        print(preloads_A2)

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused/MPI_2/A2_baking/'
        preloads_A2_baking = compute_and_write_preloads(
            base_dir, 'preloads_A2_baking.txt', N, ensemble_size, n_qoi)
        print(preloads_A2_baking)

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused/MPI_2/B2/'
        preloads_B2 = compute_and_write_preloads(base_dir, 'preloads_B2.txt',
                                                 N, ensemble_size, n_qoi)
        print(preloads_B2)

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused/MPI_2/B2_baking/'
        preloads_B2_baking = compute_and_write_preloads(
            base_dir, 'preloads_B2_baking.txt', N, ensemble_size, n_qoi)
        print(preloads_B2_baking)

        np.savetxt('preloads_A2_dif.txt', preloads_A2 - preloads_A2_baking)
        np.savetxt('preloads_B2_dif.txt', preloads_B2 - preloads_B2_baking)

        N = 79

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused_preload/MPI_2/A2/'
        preloads_A2_N = compute_and_write_preloads(base_dir,
                                                   'preloads_A2_N.txt', N,
                                                   ensemble_size, n_qoi)

        print(preloads_A2_N)

        np.savetxt('preloads_A2_N_dif.txt',
                   preloads_A2_N - preloads_A2_baking[0])

        base_dir = file_dir + \
            '/../../../workspace/katoptron_Juelich_tests_M1_assembly_fused_preload/MPI_2/B2/'
        preloads_B2_N = compute_and_write_preloads(base_dir,
                                                   'preloads_B2_N.txt', N,
                                                   ensemble_size, n_qoi)

        print(preloads_B2_N)

        np.savetxt('preloads_B2_N_dif.txt',
                   preloads_B2_N - preloads_B2_baking[0])
    else:
        N = 20
        loaded = np.load(file_dir + '/../samples_files/Xiao_' + str(N) +
                         '.npz')
        samples = loaded['samples']
        N = samples.shape[0]

        preloads_A2_N = np.loadtxt('preloads_A2_N.txt')
        preloads_B2_N = np.loadtxt('preloads_B2_N.txt')

        tmp = np.zeros((N, 3))
        tmp[:, 0] = samples[:, 0]
        tmp[:, 1] = samples[:, 1]
        tmp[:, 2] = preloads_A2_N[:, 0]
        np.savetxt('qoi_A_P1.txt', tmp, fmt='%f')
        tmp[:, 2] = preloads_A2_N[:, 1]
        np.savetxt('qoi_A_P2.txt', tmp, fmt='%f')
        tmp[:, 2] = preloads_A2_N[:, 2]
        np.savetxt('qoi_A_P3.txt', tmp, fmt='%f')

        tmp[:, 2] = preloads_B2_N[:, 0]
        np.savetxt('qoi_B_P1.txt', tmp, fmt='%f')
        tmp[:, 2] = preloads_B2_N[:, 1]
        np.savetxt('qoi_B_P2.txt', tmp, fmt='%f')
        tmp[:, 2] = preloads_B2_N[:, 2]
        np.savetxt('qoi_B_P3.txt', tmp, fmt='%f')

        print(np.amin(preloads_A2_N[:, 0]))
        print(np.amax(preloads_A2_N[:, 0]))

        print(np.amin(preloads_A2_N[:, 1]))
        print(np.amax(preloads_A2_N[:, 1]))

        print(np.amin(preloads_A2_N[:, 2]))
        print(np.amax(preloads_A2_N[:, 2]))

        print(np.amin(preloads_B2_N[:, 0]))
        print(np.amax(preloads_B2_N[:, 0]))

        print(np.amin(preloads_B2_N[:, 1]))
        print(np.amax(preloads_B2_N[:, 1]))

        print(np.amin(preloads_B2_N[:, 2]))
        print(np.amax(preloads_B2_N[:, 2]))


if __name__ == "__main__":
    main()
