#ifndef KATOPTRON_DIRICHLET_H
#define KATOPTRON_DIRICHLET_H

#include "katoptron.h"
#include "wGroup.h"
#include <vector>
#include <string>

#include <Teuchos_RCP.hpp>

namespace katoptron
{

/**
 * @brief Class used to specify in Python the different Dirichlet boundary conditions 
 * (both mechanical and thermal).
 */
class KATOPTRON_API Dirichlet : public tbox::Group
{
public:
    std::string const &BC_name;
    std::vector<tbox::Node *> nodes;
    std::vector<int> which_dof;
    std::vector<double> values;

    std::vector<double> x_values;
    std::vector<double> y_values;
    std::vector<double> z_values;
    std::vector<double> T_values;

    Dirichlet(Problem &pbl,
              std::string const &name,
              std::string const &_BC_name,
              std::vector<int> _which_dof,
              std::vector<double> _values,
              size_t ensemble_size = 1);

    Dirichlet(Problem &pbl,
              std::string const &name,
              std::string const &_BC_name,
              int x,
              double v_x,
              int y,
              double v_y,
              int z,
              double v_z,
              int T = 0,
              double v_T = 0,
              size_t ensemble_size = 1);

    Dirichlet(Problem &pbl,
              std::string const &name,
              std::string const &_BC_name,
              int x,
              std::vector<double> v_x,
              int y,
              std::vector<double> v_y,
              int z,
              std::vector<double> v_z,
              int T = 0,
              std::vector<double> v_T = {});

#ifndef SWIG
    virtual void write(std::ostream &out) const;
#endif
};

} // namespace katoptron

#endif //KATOPTRON_DIRICHLET_H
