#!/usr/bin/env python3
# -*- coding: utf-8; -*-




import katoptron as m
import tbox
import tbox.gmsh as gmsh
import katoptron.utilities as u
from fwk.testing import *


def main():
    comm, rank, size = u.import_MPI()

    from PyTrilinos import Teuchos
    import shlex
    import subprocess
    import os
    import numpy as np

    geo_name = '1_cube.geo'
    file_dir = os.path.dirname(__file__)
    work_dir = os.getcwd()

    msh, mesh_name, partitioned_mesh_name = u.read_mesh_MPI(
        geo_name, file_dir, work_dir, comm, rank, size)

    ensemble_size = 1

    pbl = m.Problem(msh, comm)

    E = 1. * np.ones(ensemble_size)
    nu = 0.2 * np.ones(ensemble_size)
    k = 0.114
    d = 0.

    hf = 1 * np.ones(ensemble_size)
    zero = np.zeros(ensemble_size)
    m.Medium(pbl, "Body 1", "test", E, nu, k, d)

    m.Dirichlet(pbl, "Surf 1 1", "Clamped", 1, 0.,
                1, 0., 1, 0., 1, 10., ensemble_size)
    m.Neumann(pbl, "Surf 1 2", "heat fluxes", 0, zero,
              0, zero, 0, zero, 1, hf, ensemble_size)

    dx = np.zeros(ensemble_size)
    dy = 2. * np.ones(ensemble_size)
    dz = np.zeros(ensemble_size)
    dT = 10. * np.ones(ensemble_size)

    solverList = Teuchos.ParameterList()
    solverList['Convergence Tolerance'] = 10**(-8)
    solverList['Maximum Iterations'] = 2
    solverList['Verbosity'] = 33
    solverList['Flexible Gmres'] = False
    solverList['Output Style'] = 1
    solverList['Output Frequency'] = 1

    solverList['Use preconditioner'] = True

    solverList['type'] = "BlockGmres"
    solverList['Maximum active set iteration'] = 1

    solverList['Print Teuchos timers'] = True

    mueluParams = Teuchos.ParameterList()
    mueluParams['number of equations'] = 4
    mueluParams['max levels'] = 1
    mueluParams['coarse: type'] = "RELAXATION"

    mueluParamsSub2 = Teuchos.ParameterList()
    mueluParamsSub2['relaxation: type'] = "MT Symmetric Gauss-Seidel"
    mueluParamsSub2['relaxation: sweeps'] = 1
    mueluParamsSub2['relaxation: damping factor'] = 0.9

    mueluParams['verbosity'] = "low"

    mueluParams['coarse: params'] = mueluParamsSub2

    solverList['mueluParams'] = mueluParams
    solverList['Write txt files'] = True

    m.Kokkos_Initialize(2)
    slv = m.IterativeSolver(
        pbl, solverList, 4, ensemble_size)
    slv.start()

    m.Kokkos_Finalize()


if __name__ == "__main__":
    main()
