#!/usr/bin/env python3
# -*- coding: utf-8; -*-




from katoptron.speedup import *
import matplotlib.pyplot as plt
import os


def read_timers_all(file_base_dir, querylines, use_waves_timers,
                    use_teuchos_timers):

    timers = np.zeros((len(querylines), ))

    for k in use_waves_timers:
        timers[int(k)] = read_timers(file_base_dir + 'timers.txt',
                                     [querylines[int(k)]])[0]
    for k in use_teuchos_timers:
        timers[int(k)] = read_teuchos_timers(
            file_base_dir + 'teuchos_timers.txt', [querylines[int(k)]])[0]

    return timers


def CPU_time_per_one_case(base_dir,
                          quantiles,
                          querylines,
                          use_waves_timers,
                          use_teuchos_timers,
                          filename_CPU,
                          filename_speed_up,
                          total_id,
                          write_id,
                          block_id,
                          mult=1.):

    timers = read_timers_all(base_dir, querylines, use_waves_timers,
                             use_teuchos_timers)

    current_timer = timers*mult

    f = open(filename_CPU, 'w')
    print(timers.shape, file=f)

    for i in range(0, len(timers)):
        print(querylines[i], file=f)
        string = ''
        if i == total_id:
            current_timer[i] -= timers[write_id]
            current_timer[i] -= timers[block_id]

        string = string + str(round(current_timer[i], 3)) + ' & '
        print(string, file=f)
        print(' ', file=f)
    f.closed

    return current_timer


def analysis_one_case(directory,
                      base_dir,
                      quantiles,
                      querylines,
                      use_waves_timers,
                      use_teuchos_timers,
                      mult=1.):
    if not os.path.exists(directory):
        os.makedirs(directory)
    os.chdir(directory)

    current_timer = CPU_time_per_one_case(base_dir,
                                          quantiles,
                                          querylines,
                                          use_waves_timers,
                                          use_teuchos_timers,
                                          'average_CPU.txt',
                                          'average_speed_up.txt',
                                          7,
                                          8,
                                          9,
                                          mult=mult)

    os.chdir('..')
    return current_timer


def main():
    import matplotlib.pyplot as plt

    file_dir = os.path.dirname(__file__)

    quantiles = [0, 0.33, 0.5, 0.66, 1.]

    querylines = [
        'computeMatrices',
        'MueLu: Hierarchy: Setup (total)',
        'Belos: DGKS[2]: Orthogonalization',
        'Belos: Operation Op*x',
        'Belos: Operation Prec*x',
        'MueLu: Hierarchy: Solve : coarse (level=0)',
        'Belos: PseudoBlockGmresSolMgr total solve time',
        'total',
        'write results',
        'create the block matrix'
    ]
    use_waves_timers = np.array([0, 7, 8, 9], dtype=int)
    use_teuchos_timers = np.array(
        [1, 2, 3, 4, 5, 6],
        dtype=int)

    base_dir = file_dir + \
        '/../../../workspace/katoptron_thesis_test_6_1_cube/test_1_s_1_rank_0/'
    mult = 24

    directory = 'option_1'
    current_timer_1 = analysis_one_case(directory, base_dir,
                                        quantiles, querylines, use_waves_timers,
                                        use_teuchos_timers, mult=mult)

    base_dir = file_dir + \
        '/../../../workspace/katoptron_thesis_test_6_1_cube/test_2_s_1_rank_0/'
    mult = 24

    directory = 'option_2'
    current_timer_2 = analysis_one_case(directory, base_dir,
                                        quantiles, querylines, use_waves_timers,
                                        use_teuchos_timers, mult=mult)

    base_dir = file_dir + \
        '/../../../workspace/katoptron_thesis_test_6_1_cube/test_4_s_1_rank_0/'
    mult = 1

    directory = 'option_3'
    current_timer_3 = analysis_one_case(directory, base_dir,
                                        quantiles, querylines, use_waves_timers,
                                        use_teuchos_timers, mult=mult)

    base_dir = file_dir + \
        '/../../../workspace/katoptron_thesis_test_6_1_cube/test_3_s_8_rank_0/'
    mult = 3

    directory = 'option_4'
    current_timer_4 = analysis_one_case(directory, base_dir,
                                        quantiles, querylines, use_waves_timers,
                                        use_teuchos_timers, mult=mult)

    tmp = np.zeros((len(current_timer_1), 4))
    tmp[:, 0] = current_timer_1
    tmp[:, 1] = current_timer_2
    tmp[:, 2] = current_timer_3
    tmp[:, 3] = current_timer_4

    np.savetxt('all.txt', tmp, fmt='%1.3f')

    tmp_2 = np.copy(tmp)

    tmp_2[:, 0] /= tmp_2[:, 1]
    tmp_2[:, 2] /= tmp_2[:, 1]
    tmp_2[:, 3] /= tmp_2[:, 1]
    tmp_2[:, 1] /= tmp_2[:, 1]

    speed_up = 1./tmp_2

    np.savetxt('speed_up.txt', speed_up, fmt='%1.3f')


if __name__ == "__main__":
    main()
